( cd usr/lib/gcc-lib/i386-slackware-linux/3.1/include ; rm -rf X11 )
( cd usr/lib/gcc-lib/i386-slackware-linux/3.1/include ; ln -sf root/usr/X11R6/include/X11 X11 )
( cd usr/lib ; rm -rf libgcc_s.so )
( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/bin ; rm -rf gcc )
( cd usr/bin ; ln -sf gcc-3.1 gcc )
( cd usr/bin ; rm -rf i386-slackware-linux-gcc )
( cd usr/bin ; ln -sf gcc-3.1 i386-slackware-linux-gcc )
( cd usr/bin ; rm -rf cc )
( cd usr/bin ; ln -sf gcc cc )
( cd usr/man/man1 ; rm -rf cc.1.gz )
( cd usr/man/man1 ; ln -sf gcc.1.gz cc.1.gz )
( cd lib ; rm -rf cpp )
( cd lib ; ln -sf /usr/bin/cpp cpp )
